GraduateWhirlpoolCpiBuilder

Struct GraduateWhirlpoolCpiBuilder 

pub struct GraduateWhirlpoolCpiBuilder<'a, 'b> { /* private fields */ }
Instruction builder for GraduateWhirlpool via CPI.

Accounts:

  1. [writable, signer] signer
  2. [] lp_authority
  3. [writable] bonding_curve
  4. [] quote_mint
  5. [writable] quote_vault
  6. [writable] signer_quote_ata
  7. [writable] lp_authority_quote_ata
  8. [writable] whirlpool_quote_vault
  9. [writable] base_mint
  10. [writable] base_vault
  11. [writable] lp_authority_base_ata
  12. [writable] whirlpool_base_vault
  13. [] whirlpool_config
  14. [] fee_tier
  15. [writable] whirlpool
  16. [writable] oracle
  17. [writable] position
  18. [writable] position_mint
  19. [writable] position_token_account
  20. [writable] lp_authority_token_account
  21. [writable] lower_tick_array
  22. [writable] upper_tick_array
  23. [] quote_token_badge
  24. [] base_token_badge
  25. [] whirlpool_init_authority
  26. [] whirlpool_update_authority
  27. [writable] lock_config
  28. [] system_program
  29. [] ata_program
  30. [] quote_token_program
  31. [] base_token_program
  32. [] token22_program
  33. [] memo_program
  34. [] whirlpool_program
  35. [] rent

Implementations

Source

impl<'a, 'b> GraduateWhirlpoolCpiBuilder<'a, 'b>

pub fn new(program: &'b AccountInfo<'a>) -> Self

pub fn signer(&mut self, signer: &'b AccountInfo<'a>) -> &mut Self

The signer of the transaction

pub fn lp_authority(&mut self, lp_authority: &'b AccountInfo<'a>) -> &mut Self

The lp authority of the token

pub fn bonding_curve(&mut self, bonding_curve: &'b AccountInfo<'a>) -> &mut Self

The bonding curve account

pub fn quote_mint(&mut self, quote_mint: &'b AccountInfo<'a>) -> &mut Self

The quote token mint account

pub fn quote_vault(&mut self, quote_vault: &'b AccountInfo<'a>) -> &mut Self

The quote token vault

pub fn signer_quote_ata( &mut self, signer_quote_ata: &'b AccountInfo<'a>, ) -> &mut Self

The quote token ata account

pub fn lp_authority_quote_ata( &mut self, lp_authority_quote_ata: &'b AccountInfo<'a>, ) -> &mut Self

The lp authority quote token ata account

pub fn whirlpool_quote_vault( &mut self, whirlpool_quote_vault: &'b AccountInfo<'a>, ) -> &mut Self

The whirlpool quote vault account

pub fn base_mint(&mut self, base_mint: &'b AccountInfo<'a>) -> &mut Self

The base token mint account

pub fn base_vault(&mut self, base_vault: &'b AccountInfo<'a>) -> &mut Self

The config base vault account

pub fn lp_authority_base_ata( &mut self, lp_authority_base_ata: &'b AccountInfo<'a>, ) -> &mut Self

The lp authority base token ata account

pub fn whirlpool_base_vault( &mut self, whirlpool_base_vault: &'b AccountInfo<'a>, ) -> &mut Self

The whirlpool base vault account

pub fn whirlpool_config( &mut self, whirlpool_config: &'b AccountInfo<'a>, ) -> &mut Self

The whirlpool config account

pub fn fee_tier(&mut self, fee_tier: &'b AccountInfo<'a>) -> &mut Self

The fee tier account

pub fn whirlpool(&mut self, whirlpool: &'b AccountInfo<'a>) -> &mut Self

The whirlpool account

pub fn oracle(&mut self, oracle: &'b AccountInfo<'a>) -> &mut Self

The whirlpool oracle account

pub fn position(&mut self, position: &'b AccountInfo<'a>) -> &mut Self

The position account

pub fn position_mint(&mut self, position_mint: &'b AccountInfo<'a>) -> &mut Self

The position mint account

pub fn position_token_account( &mut self, position_token_account: &'b AccountInfo<'a>, ) -> &mut Self

The position token account for the bonding curve

pub fn lp_authority_token_account( &mut self, lp_authority_token_account: &'b AccountInfo<'a>, ) -> &mut Self

The position token account for the lp authority

pub fn lower_tick_array( &mut self, lower_tick_array: &'b AccountInfo<'a>, ) -> &mut Self

The lower tick array account

pub fn upper_tick_array( &mut self, upper_tick_array: &'b AccountInfo<'a>, ) -> &mut Self

The upper tick array account

pub fn quote_token_badge( &mut self, quote_token_badge: &'b AccountInfo<'a>, ) -> &mut Self

The quote token badge account

pub fn base_token_badge( &mut self, base_token_badge: &'b AccountInfo<'a>, ) -> &mut Self

The base token badge account

pub fn whirlpool_init_authority( &mut self, whirlpool_init_authority: &'b AccountInfo<'a>, ) -> &mut Self

The whirlpool init authority account

pub fn whirlpool_update_authority( &mut self, whirlpool_update_authority: &'b AccountInfo<'a>, ) -> &mut Self

The whirlpool update authority account

pub fn lock_config(&mut self, lock_config: &'b AccountInfo<'a>) -> &mut Self

The lock config account

pub fn system_program( &mut self, system_program: &'b AccountInfo<'a>, ) -> &mut Self

The system program

pub fn ata_program(&mut self, ata_program: &'b AccountInfo<'a>) -> &mut Self

The ata program

pub fn quote_token_program( &mut self, quote_token_program: &'b AccountInfo<'a>, ) -> &mut Self

The quote token program

pub fn base_token_program( &mut self, base_token_program: &'b AccountInfo<'a>, ) -> &mut Self

The base token program

pub fn token22_program( &mut self, token22_program: &'b AccountInfo<'a>, ) -> &mut Self

The token 22 program

pub fn memo_program(&mut self, memo_program: &'b AccountInfo<'a>) -> &mut Self

The memo program

pub fn whirlpool_program( &mut self, whirlpool_program: &'b AccountInfo<'a>, ) -> &mut Self

The whirlpool program

pub fn rent(&mut self, rent: &'b AccountInfo<'a>) -> &mut Self

The rent sysvar

pub fn add_remaining_account( &mut self, account: &'b AccountInfo<'a>, is_writable: bool, is_signer: bool, ) -> &mut Self

Add an additional account to the instruction.

pub fn add_remaining_accounts( &mut self, accounts: &[(&'b AccountInfo<'a>, bool, bool)], ) -> &mut Self

Add additional accounts to the instruction.

Each account is represented by a tuple of the AccountInfo, a bool indicating whether the account is writable or not, and a bool indicating whether the account is a signer or not.

pub fn invoke(&self) -> ProgramResult

pub fn invoke_signed(&self, signers_seeds: &[&[&[u8]]]) -> ProgramResult