pub struct PermissionConsumeTopLevelInstructionArgs {
pub permission_message: PermissionMessage,
pub permission_signature: PermissionSignature,
}Fields
permission_message: PermissionMessagepermission_signature: PermissionSignatureTrait Implementations
Sourceimpl BorshDeserialize for PermissionConsumeTopLevelInstructionArgs
impl BorshDeserialize for PermissionConsumeTopLevelInstructionArgs
fn deserialize_reader<__R: Read>(reader: &mut __R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl Clone for PermissionConsumeTopLevelInstructionArgs
impl Clone for PermissionConsumeTopLevelInstructionArgs
Sourcefn clone(&self) -> PermissionConsumeTopLevelInstructionArgs
fn clone(&self) -> PermissionConsumeTopLevelInstructionArgs
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl PartialEq for PermissionConsumeTopLevelInstructionArgs
impl PartialEq for PermissionConsumeTopLevelInstructionArgs
Sourcefn eq(&self, other: &PermissionConsumeTopLevelInstructionArgs) -> bool
fn eq(&self, other: &PermissionConsumeTopLevelInstructionArgs) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for PermissionConsumeTopLevelInstructionArgs
impl StructuralPartialEq for PermissionConsumeTopLevelInstructionArgs